@@ -731,8 +731,9 @@ static Bool MGADRIBootstrapDMA(ScreenPtr pScreen)
 	    return FALSE;
 	}
 	xf86DrvMsg( pScreen->myNum, X_INFO,
-		    "[agp] %d kB allocated with handle 0x%08lx\n",
-		    pMGADRIServer->agp.size/1024, pMGADRIServer->agp.handle );
+ 		    "[agp] %d kB allocated with handle 0x%08x\n",
+		    pMGADRIServer->agp.size/1024, 
+		    (unsigned int) pMGADRIServer->agp.handle );
 
 	if ( drmAgpBind( pMga->drmFD, pMGADRIServer->agp.handle, 0 ) < 0 ) {
 	    xf86DrvMsg( pScreen->myNum, X_ERROR, "[agp] Could not bind memory\n" );
@@ -753,8 +754,8 @@ static Bool MGADRIBootstrapDMA(ScreenPtr pScreen)
 	    return FALSE;
 	}
 	xf86DrvMsg( pScreen->myNum, X_INFO,
-		    "[agp] WARP microcode handle = 0x%08lx\n",
-		    pMGADRIServer->warp.handle );
+ 		    "[agp] WARP microcode handle = 0x%08x\n",
+		    (unsigned int) pMGADRIServer->warp.handle );
 
 	/* Primary DMA space
 	 */
@@ -768,8 +769,8 @@ static Bool MGADRIBootstrapDMA(ScreenPtr pScreen)
 	    return FALSE;
 	}
 	xf86DrvMsg( pScreen->myNum, X_INFO,
-		    "[agp] Primary DMA handle = 0x%08lx\n",
-		    pMGADRIServer->primary.handle );
+ 		    "[agp] Primary DMA handle = 0x%08x\n",
+		    (unsigned int) pMGADRIServer->primary.handle );
 
 	/* DMA buffers
 	 */
@@ -783,8 +784,8 @@ static Bool MGADRIBootstrapDMA(ScreenPtr pScreen)
 	    return FALSE;
 	}
 	xf86DrvMsg( pScreen->myNum, X_INFO,
-		    "[agp] DMA buffers handle = 0x%08lx\n",
-		    pMGADRIServer->buffers.handle );
+ 		    "[agp] DMA buffers handle = 0x%08x\n",
+		    (unsigned int) pMGADRIServer->buffers.handle );
 
 	count = drmAddBufs( pMga->drmFD,
 			    MGA_NUM_BUFFERS, MGA_BUFFER_SIZE,
@@ -815,8 +816,8 @@ static Bool MGADRIBootstrapDMA(ScreenPtr pScreen)
 	}
 
 	xf86DrvMsg( pScreen->myNum, X_INFO,
-		    "[agp] agpTexture handle = 0x%08lx\n",
-		    pMGADRIServer->agpTextures.handle );
+ 		    "[agp] agpTexture handle = 0x%08x\n",
+		    (unsigned int) pMGADRIServer->agpTextures.handle );
 	xf86DrvMsg( pScreen->myNum, X_INFO,
 		    "[agp] agpTexture size: %d kb\n", pMGADRIServer->agpTextures.size/1024 );
 
@@ -832,8 +833,8 @@ static Bool MGADRIBootstrapDMA(ScreenPtr pScreen)
 	    return FALSE;
 	}
 	xf86DrvMsg( pScreen->myNum, X_INFO,
-		    "[drm] Registers handle = 0x%08lx\n",
-		    pMGADRIServer->registers.handle );
+ 		    "[drm] Registers handle = 0x%08x\n",
+		    (unsigned int) pMGADRIServer->registers.handle );
 
 	pMGADRIServer->status.size = SAREA_MAX;
 
@@ -845,8 +846,8 @@ static Bool MGADRIBootstrapDMA(ScreenPtr pScreen)
 	    return FALSE;
 	}
 	xf86DrvMsg( pScreen->myNum, X_INFO,
-		    "[drm] Status handle = 0x%08lx\n",
-		    pMGADRIServer->status.handle );
+ 		    "[drm] Status handle = 0x%08x\n",
+		    (unsigned int) pMGADRIServer->status.handle );
     }
 
     return TRUE;
